import React from 'react';
import Avatar from '../Avatar';
import renderer from 'react-test-renderer';
let avatarURL = 'avatar.jpg';
describe('Avatar component', () => {
  it('should display initial', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display avatar image and initial while avatar loading...', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display initial if invalid url', () => {
    Avatar.invalidImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should display image valid url', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the palette is default', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      palette: "default"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the palette is secondary', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      palette: "secondary"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the palette is info', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      palette: "info"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the shape is square', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      shape: "square"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the size is small', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      size: "square"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the size is xsmall', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      size: "xsmall"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the size is xmedium', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      size: "xmedium"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the size is large', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      size: "large"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should the size is xlarge', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      size: "xlarge"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should have title', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      title: "Sample Title"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should no need title', () => {
    Avatar.invalidImageURLs.length = 0;
    Avatar.validImageURLs.push(avatarURL);
    let ele = renderer.create( /*#__PURE__*/React.createElement(Avatar, {
      name: "vimalesan a",
      src: avatarURL,
      needTitle: false
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});