/* eslint-disable no-undef */
import React from 'react';
import Label from '../Label';
import renderer from 'react-test-renderer';
describe('Label Props Check', () => {
  it('Display proper text', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Label, {
      text: "text1"
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'label').textContent).toMatch(/text1/);
  });
  it('Check if clipped style is applied', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      clipped: true
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'label').className).toMatch(/dotted/);
  });
  it('Check if clipped style is not applied', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      clipped: false
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'label').className).not.toMatch(/dotted/);
  });
  it('Check for the prop name', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      name: "1234"
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'label').getAttribute('name')).toMatch(/1234/);
  });
  it('Check for the prop title', () => {
    let renderedDOM = TestUtils.renderIntoDocument( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      title: "1234"
    }));
    expect(TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'label').getAttribute('data-title')).toMatch(/1234/);
  });
  it('should be having palette default', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      palette: "default"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having palette primary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      palette: "primary"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having palette secondary', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      palette: "secondary"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having palette danger', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      palette: "danger"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having palette mandatory', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      palette: "mandatory"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having size small', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      size: "small"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having size medium', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      size: "medium"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having size large', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      size: "large"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having type title', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      type: "title"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
  it('should be having type subtitle', () => {
    let ele = renderer.create( /*#__PURE__*/React.createElement(Label, {
      text: "text1",
      type: "subtitle"
    }));
    let tree = ele.toJSON();
    expect(tree).toMatchSnapshot();
  });
});