/* eslint-disable no-undef */

/**** Libraries ****/
import expect from 'expect';
/**** Components ****/

import MultiSelect from '../MultiSelect';
import Tag from '../../Tag/Tag';
describe('MultiSelect component conditions', () => {
  it('Should show loading and hide loading', cb => {
    let resolveFunc = null;
    let newPromise = new Promise(res => {
      resolveFunc = res;
    });
    let searchDebounceTime = 0;
    let {
      renderedDOM,
      props
    } = setup(MultiSelect, {
      onSearch: jest.fn(() => newPromise),
      needSearch: true,
      searchDebounceTime,
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    });
    let searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_textBox');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    }); //

    setTimeout(() => {
      expect(props.onSearch).toHaveBeenCalled();
      expect(props.onSearch.mock.calls[0][0]).toEqual('value changed');
      let loadingEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_Loading');
      expect(TestUtils.isDOMComponent(loadingEle)).toBeTruthy();
      resolveFunc();
      return newPromise.then(() => {
        let loadingEleArr = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_Loading');
        expect(loadingEleArr.length).toBe(0);
        cb();
      });
    }, searchDebounceTime); //
  });
  it('Should display searchEmptyMessage', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    });
    let searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_textBox');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    });
    let searchEmptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_srchEmptyMsg');
    expect(TestUtils.isDOMComponent(searchEmptyMessageEle)).toBeTruthy();
  });
  it('Should display noOptionsMessage', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    });
    let emptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_noOptnsMsg');
    expect(TestUtils.isDOMComponent(emptyMessageEle)).toBeTruthy();
  });
  it('Should display noMoreOptionsMessage', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2', '3', '4'],
      dataIdNoMreOptionMsg: 'noMoreOptionsMessage',
      isPopupOpen: true
    });
    let noMoreOptionsMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_NoMoreOptionMsg');
    expect(TestUtils.isDOMComponent(noMoreOptionsMessageEle)).toBeTruthy();
  });
  it('Should display clear icon', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2']
    });
    let clearIconEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    expect(TestUtils.isDOMComponent(clearIconEle)).toBeTruthy();
  });
  it('Should not display clear icon, When is readonly field', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2'],
      isReadOnly: true
    });
    let clearIconEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    expect(clearIconEles.length).toBe(0);
  });
  it('Should not display clear icon, When is selected option is one', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1']
    });
    let clearIconEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    expect(clearIconEles.length).toBe(0);
  });
  it('Should display select all option, When suggestions are more than 1', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2'],
      isPopupOpen: true,
      needSelectAll: true
    });
    let selectAllEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_selectAll');
    expect(TestUtils.isDOMComponent(selectAllEle)).toBeTruthy();
  });
  it('Should not display select all option', () => {
    let {
      renderedDOM
    } = setup(MultiSelect, {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2', '3'],
      isPopupOpen: true,
      needSelectAll: true
    });
    let selectAllEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_MultiSelectHeader');
    expect(selectAllEles.length).toBe(0);
  });
});