/* eslint-disable no-undef */

/**** Libraries ****/
import expect from 'expect';
/**** Components ****/

import Select from '../Select';
import ListItem from '../../ListItem/ListItem';
describe('Select component conditions', () => {
  it('Select component with down arrow', () => {
    let {
      renderedDOM
    } = setup(Select, {
      needSelectDownIcon: true,
      dataId: 'selectComp'
    });
    let downIconEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_downIcon');
    expect(TestUtils.isDOMComponent(downIconEle)).toBeTruthy();
  });
  it('Select component without down arrow', () => {
    let {
      renderedDOM
    } = setup(Select, {
      needSelectDownIcon: false,
      dataId: 'selectComp'
    });
    let downIcons = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_downIcon');
    expect(downIcons.length).toBe(0);
  });
  it('Select component with search box', () => {
    let {
      renderedDOM
    } = setup(Select, {
      needSearch: true,
      isPopupOpen: true,
      isPopupReady: true,
      dataId: 'selectComp'
    });
    let textBoxes = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_search');
    expect(textBoxes.length).toBe(1);
  });
  it('Select component without search box', () => {
    let {
      renderedDOM
    } = setup(Select, {
      needSearch: false,
      isPopupOpen: true,
      dataId: 'selectComp'
    });
    let textBoxes = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_search');
    expect(textBoxes.length).toBe(0);
  });
  it('Should Show empty message', () => {
    let {
      renderedDOM
    } = setup(Select, {
      isPopupOpen: true,
      dataId: 'selectComp'
    });
    let emptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_noOptnsMsg');
    expect(TestUtils.isDOMComponent(emptyMessageEle)).toBeTruthy();
  });
  it('Should render suggestions, When popup open', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp',
      isPopupOpen: true
    });
    let suggestionsContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(TestUtils.isDOMComponent(suggestionsContainer)).toBeTruthy();
  });
  it('Should not render suggestions, When popup close', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp',
      isPopupOpen: false
    });
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(suggestionsContainer.length).toBe(0);
  });
  it('Should popup open, When click textBox', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'TextBox'
    });
    let targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextBox');
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'TextBox_suggestions');
    expect(suggestionsContainer.length).toBe(0);
    TestUtils.Simulate.click(targetTextBox);
    let suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextBox_suggestions');
    expect(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
  });
  it('Should popup open, When down arrow press', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp'
    });
    let targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_textBox');
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(suggestionsContainer.length).toBe(0);
    TestUtils.Simulate.keyDown(targetTextBox, {
      keyCode: 40
    });
    let suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
  });
  xit('Should popup close, When esc key press', () => {
    //popup close handling in popup component
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp',
      isPopupOpen: true
    });
    let suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
    let targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp');
    TestUtils.Simulate.keyDown(targetTextBox, {
      keyCode: 27
    });
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(suggestionsContainer.length).toBe(0);
  });
  it('Should not popup open, When is readOnly component', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp',
      isReadOnly: true
    });
    let targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_readOnly');
    TestUtils.Simulate.click(targetTextBox);
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(suggestionsContainer.length).toBe(0);
  });
  it('Should not popup open, When is disabled component', () => {
    let {
      renderedDOM
    } = setup(Select, {
      dataId: 'selectComp',
      isDisabled: true
    });
    let targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_disabled');
    TestUtils.Simulate.click(targetTextBox);
    let suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    expect(suggestionsContainer.length).toBe(0);
  });
  it('Should Show search empty message', () => {
    let {
      renderedDOM
    } = setup(Select, {
      needSearch: true,
      isPopupOpen: true,
      dataId: 'textBox'
    });
    let [searchBox] = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_search');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    });
    let emptyMessageEle = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_noOptnsMsg');
    let searchEmptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'textBox_srchEmptyMsg');
    expect(emptyMessageEle.length).toBe(0);
    expect(TestUtils.isDOMComponent(searchEmptyMessageEle)).toBeTruthy();
  });
  it('Should show loading and hide loading', cb => {
    let resolveFunc = null;
    let newPromise = new Promise(res => {
      resolveFunc = res;
    });
    let searchDebounceTime = 0;
    let {
      renderedDOM,
      props
    } = setup(Select, {
      onSearch: jest.fn(() => newPromise),
      needSearch: true,
      searchDebounceTime,
      isPopupOpen: true,
      dataId: 'textBox'
    });
    let [searchBox] = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_search');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    }); //

    setTimeout(() => {
      expect(props.onSearch).toHaveBeenCalled();
      expect(props.onSearch.mock.calls[0][0]).toEqual('value changed');
      let loadingEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'textBox_Loading');
      expect(TestUtils.isDOMComponent(loadingEle)).toBeTruthy();
      resolveFunc();
      return newPromise.then(() => {
        let loadingEleArr = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_Loading');
        expect(loadingEleArr.length).toBe(0);
        cb();
      });
    }, searchDebounceTime); //
  });
  it('Should call onChange, When select list item', () => {
    let defaultProps = {
      options: [{
        id: '1',
        text: 'one'
      }, {
        id: '2',
        text: 'two'
      }],
      onChange: jest.fn(),
      isPopupOpen: true
    };
    let {
      renderedDOM,
      props
    } = setup(Select, defaultProps);
    let [listItem] = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'one');
    TestUtils.Simulate.click(listItem);
    expect(props.onChange).toHaveBeenCalledWith('1', {
      id: '1',
      text: 'one'
    });
  });
  it('Should not call onChange func, When is readonly component', () => {
    let defaultProps = {
      options: [{
        id: '1',
        text: 'one'
      }, {
        id: '2',
        text: 'two'
      }],
      onChange: jest.fn(),
      isReadOnly: true
    };
    let {
      renderedDOM
    } = setup(Select, defaultProps);
    let listItems = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, '1');
    expect(listItems.length).toBe(0);
  });
  it('Should call getNextOptions, When on reach boundary and isNextOptions is true', () => {
    let defaultProps = {
      options: [1, 2, 3, 4, 5],
      getNextOptions: jest.fn(),
      isNextOptions: true,
      isPopupOpen: true
    };
    let {
      renderedDOM,
      props
    } = setup(Select, defaultProps);
    let searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    expect(props.getNextOptions).toHaveBeenCalled();
  });
  it('Should not call getNextOptions, When on reach boundary and isNextOptions is false', () => {
    let defaultProps = {
      options: [1, 2, 3, 4, 5],
      getNextOptions: jest.fn(),
      isNextOptions: false,
      isPopupOpen: true
    };
    let {
      renderedDOM,
      props
    } = setup(Select, defaultProps);
    let searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    expect(props.getNextOptions).not.toHaveBeenCalled();
  });
  it('Should ignore excludeOptions', () => {
    let defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      excludeOptions: ['1', '2'],
      isPopupOpen: true
    };
    let {
      renderedDOM
    } = setup(Select, defaultProps); // let liteItemArr = TestUtils.scryRenderedComponentsWithTestid(
    //   renderedDOM,
    //   'listItem'
    // );

    let liteItemArr = TestUtils.scryRenderedComponentsWithType(renderedDOM, ListItem);
    expect(liteItemArr.length).toBe(3);
  });
  it('Should select defaultValue', () => {
    let defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      isDefaultSelectValue: true
    };
    let {
      renderedDOM
    } = setup(Select, defaultProps);
    let selectComp = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    expect(selectComp.value).toBe('1');
  });
  it('Should not select defaultValue', () => {
    let defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      isDefaultSelectValue: false
    };
    let {
      renderedDOM
    } = setup(Select, defaultProps);
    let selectComp = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    expect(selectComp.value).toBe('');
  });
  it('Should active selected value', () => {
    let defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      selectedValue: '1',
      isPopupOpen: true
    };
    let {
      renderedDOM
    } = setup(Select, defaultProps);
    let [listItem1, listItem2] = TestUtils.scryRenderedComponentsWithType(renderedDOM, ListItem);
    expect(listItem1.props.active).toBeTruthy();
    expect(listItem2.props.active).toBeFalsy();
  });
});