"use strict";

var _expect = _interopRequireDefault(require("expect"));

var _MultiSelect = _interopRequireDefault(require("../MultiSelect"));

var _Tag = _interopRequireDefault(require("../../Tag/Tag"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

/* eslint-disable no-undef */

/**** Libraries ****/

/**** Components ****/
describe('MultiSelect component conditions', function () {
  it('Should show loading and hide loading', function (cb) {
    var resolveFunc = null;
    var newPromise = new Promise(function (res) {
      resolveFunc = res;
    });
    var searchDebounceTime = 0;

    var _setup = setup(_MultiSelect["default"], {
      onSearch: jest.fn(function () {
        return newPromise;
      }),
      needSearch: true,
      searchDebounceTime: searchDebounceTime,
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    }),
        renderedDOM = _setup.renderedDOM,
        props = _setup.props;

    var searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_textBox');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    }); //

    setTimeout(function () {
      (0, _expect["default"])(props.onSearch).toHaveBeenCalled();
      (0, _expect["default"])(props.onSearch.mock.calls[0][0]).toEqual('value changed');
      var loadingEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_Loading');
      (0, _expect["default"])(TestUtils.isDOMComponent(loadingEle)).toBeTruthy();
      resolveFunc();
      return newPromise.then(function () {
        var loadingEleArr = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_Loading');
        (0, _expect["default"])(loadingEleArr.length).toBe(0);
        cb();
      });
    }, searchDebounceTime); //
  });
  it('Should display searchEmptyMessage', function () {
    var _setup2 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    }),
        renderedDOM = _setup2.renderedDOM;

    var searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_textBox');
    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    });
    var searchEmptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_srchEmptyMsg');
    (0, _expect["default"])(TestUtils.isDOMComponent(searchEmptyMessageEle)).toBeTruthy();
  });
  it('Should display noOptionsMessage', function () {
    var _setup3 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: [],
      selectedOptions: [],
      isPopupOpen: true
    }),
        renderedDOM = _setup3.renderedDOM;

    var emptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_noOptnsMsg');
    (0, _expect["default"])(TestUtils.isDOMComponent(emptyMessageEle)).toBeTruthy();
  });
  it('Should display noMoreOptionsMessage', function () {
    var _setup4 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2', '3', '4'],
      dataIdNoMreOptionMsg: 'noMoreOptionsMessage',
      isPopupOpen: true
    }),
        renderedDOM = _setup4.renderedDOM;

    var noMoreOptionsMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_NoMoreOptionMsg');
    (0, _expect["default"])(TestUtils.isDOMComponent(noMoreOptionsMessageEle)).toBeTruthy();
  });
  it('Should display clear icon', function () {
    var _setup5 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2']
    }),
        renderedDOM = _setup5.renderedDOM;

    var clearIconEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    (0, _expect["default"])(TestUtils.isDOMComponent(clearIconEle)).toBeTruthy();
  });
  it('Should not display clear icon, When is readonly field', function () {
    var _setup6 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2'],
      isReadOnly: true
    }),
        renderedDOM = _setup6.renderedDOM;

    var clearIconEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    (0, _expect["default"])(clearIconEles.length).toBe(0);
  });
  it('Should not display clear icon, When is selected option is one', function () {
    var _setup7 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1']
    }),
        renderedDOM = _setup7.renderedDOM;

    var clearIconEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_clearIcon');
    (0, _expect["default"])(clearIconEles.length).toBe(0);
  });
  it('Should display select all option, When suggestions are more than 1', function () {
    var _setup8 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2'],
      isPopupOpen: true,
      needSelectAll: true
    }),
        renderedDOM = _setup8.renderedDOM;

    var selectAllEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'multiSelect_selectAll');
    (0, _expect["default"])(TestUtils.isDOMComponent(selectAllEle)).toBeTruthy();
  });
  it('Should not display select all option', function () {
    var _setup9 = setup(_MultiSelect["default"], {
      emptyMessage: '',
      onChange: jest.fn(),
      options: ['1', '2', '3', '4'],
      selectedOptions: ['1', '2', '3'],
      isPopupOpen: true,
      needSelectAll: true
    }),
        renderedDOM = _setup9.renderedDOM;

    var selectAllEles = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'multiSelect_MultiSelectHeader');
    (0, _expect["default"])(selectAllEles.length).toBe(0);
  });
});