"use strict";

var _expect = _interopRequireDefault(require("expect"));

var _Select = _interopRequireDefault(require("../Select"));

var _ListItem = _interopRequireDefault(require("../../ListItem/ListItem"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

describe('Select component conditions', function () {
  it('Select component with down arrow', function () {
    var _setup = setup(_Select["default"], {
      needSelectDownIcon: true,
      dataId: 'selectComp'
    }),
        renderedDOM = _setup.renderedDOM;

    var downIconEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_downIcon');
    (0, _expect["default"])(TestUtils.isDOMComponent(downIconEle)).toBeTruthy();
  });
  it('Select component without down arrow', function () {
    var _setup2 = setup(_Select["default"], {
      needSelectDownIcon: false,
      dataId: 'selectComp'
    }),
        renderedDOM = _setup2.renderedDOM;

    var downIcons = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_downIcon');
    (0, _expect["default"])(downIcons.length).toBe(0);
  });
  it('Select component with search box', function () {
    var _setup3 = setup(_Select["default"], {
      needSearch: true,
      isPopupOpen: true,
      isPopupReady: true,
      dataId: 'selectComp'
    }),
        renderedDOM = _setup3.renderedDOM;

    var textBoxes = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_search');
    (0, _expect["default"])(textBoxes.length).toBe(1);
  });
  it('Select component without search box', function () {
    var _setup4 = setup(_Select["default"], {
      needSearch: false,
      isPopupOpen: true,
      dataId: 'selectComp'
    }),
        renderedDOM = _setup4.renderedDOM;

    var textBoxes = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_search');
    (0, _expect["default"])(textBoxes.length).toBe(0);
  });
  it('Should Show empty message', function () {
    var _setup5 = setup(_Select["default"], {
      isPopupOpen: true,
      dataId: 'selectComp'
    }),
        renderedDOM = _setup5.renderedDOM;

    var emptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_noOptnsMsg');
    (0, _expect["default"])(TestUtils.isDOMComponent(emptyMessageEle)).toBeTruthy();
  });
  it('Should render suggestions, When popup open', function () {
    var _setup6 = setup(_Select["default"], {
      dataId: 'selectComp',
      isPopupOpen: true
    }),
        renderedDOM = _setup6.renderedDOM;

    var suggestionsContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(TestUtils.isDOMComponent(suggestionsContainer)).toBeTruthy();
  });
  it('Should not render suggestions, When popup close', function () {
    var _setup7 = setup(_Select["default"], {
      dataId: 'selectComp',
      isPopupOpen: false
    }),
        renderedDOM = _setup7.renderedDOM;

    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
  });
  it('Should popup open, When click textBox', function () {
    var _setup8 = setup(_Select["default"], {
      dataId: 'TextBox'
    }),
        renderedDOM = _setup8.renderedDOM;

    var targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextBox');
    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'TextBox_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
    TestUtils.Simulate.click(targetTextBox);
    var suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'TextBox_suggestions');
    (0, _expect["default"])(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
  });
  it('Should popup open, When down arrow press', function () {
    var _setup9 = setup(_Select["default"], {
      dataId: 'selectComp'
    }),
        renderedDOM = _setup9.renderedDOM;

    var targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_textBox');
    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
    TestUtils.Simulate.keyDown(targetTextBox, {
      keyCode: 40
    });
    var suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
  });
  xit('Should popup close, When esc key press', function () {
    //popup close handling in popup component
    var _setup10 = setup(_Select["default"], {
      dataId: 'selectComp',
      isPopupOpen: true
    }),
        renderedDOM = _setup10.renderedDOM;

    var suggestionContainer = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(TestUtils.isDOMComponent(suggestionContainer)).toBeTruthy();
    var targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp');
    TestUtils.Simulate.keyDown(targetTextBox, {
      keyCode: 27
    });
    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
  });
  it('Should not popup open, When is readOnly component', function () {
    var _setup11 = setup(_Select["default"], {
      dataId: 'selectComp',
      isReadOnly: true
    }),
        renderedDOM = _setup11.renderedDOM;

    var targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_readOnly');
    TestUtils.Simulate.click(targetTextBox);
    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
  });
  it('Should not popup open, When is disabled component', function () {
    var _setup12 = setup(_Select["default"], {
      dataId: 'selectComp',
      isDisabled: true
    }),
        renderedDOM = _setup12.renderedDOM;

    var targetTextBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComp_disabled');
    TestUtils.Simulate.click(targetTextBox);
    var suggestionsContainer = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'selectComp_suggestions');
    (0, _expect["default"])(suggestionsContainer.length).toBe(0);
  });
  it('Should Show search empty message', function () {
    var _setup13 = setup(_Select["default"], {
      needSearch: true,
      isPopupOpen: true,
      dataId: 'textBox'
    }),
        renderedDOM = _setup13.renderedDOM;

    var _TestUtils$scryRender = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_search'),
        _TestUtils$scryRender2 = _slicedToArray(_TestUtils$scryRender, 1),
        searchBox = _TestUtils$scryRender2[0];

    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    });
    var emptyMessageEle = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_noOptnsMsg');
    var searchEmptyMessageEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'textBox_srchEmptyMsg');
    (0, _expect["default"])(emptyMessageEle.length).toBe(0);
    (0, _expect["default"])(TestUtils.isDOMComponent(searchEmptyMessageEle)).toBeTruthy();
  });
  it('Should show loading and hide loading', function (cb) {
    var resolveFunc = null;
    var newPromise = new Promise(function (res) {
      resolveFunc = res;
    });
    var searchDebounceTime = 0;

    var _setup14 = setup(_Select["default"], {
      onSearch: jest.fn(function () {
        return newPromise;
      }),
      needSearch: true,
      searchDebounceTime: searchDebounceTime,
      isPopupOpen: true,
      dataId: 'textBox'
    }),
        renderedDOM = _setup14.renderedDOM,
        props = _setup14.props;

    var _TestUtils$scryRender3 = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_search'),
        _TestUtils$scryRender4 = _slicedToArray(_TestUtils$scryRender3, 1),
        searchBox = _TestUtils$scryRender4[0];

    TestUtils.Simulate.change(searchBox, {
      target: {
        value: 'value changed'
      }
    }); //

    setTimeout(function () {
      (0, _expect["default"])(props.onSearch).toHaveBeenCalled();
      (0, _expect["default"])(props.onSearch.mock.calls[0][0]).toEqual('value changed');
      var loadingEle = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'textBox_Loading');
      (0, _expect["default"])(TestUtils.isDOMComponent(loadingEle)).toBeTruthy();
      resolveFunc();
      return newPromise.then(function () {
        var loadingEleArr = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'textBox_Loading');
        (0, _expect["default"])(loadingEleArr.length).toBe(0);
        cb();
      });
    }, searchDebounceTime); //
  });
  it('Should call onChange, When select list item', function () {
    var defaultProps = {
      options: [{
        id: '1',
        text: 'one'
      }, {
        id: '2',
        text: 'two'
      }],
      onChange: jest.fn(),
      isPopupOpen: true
    };

    var _setup15 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup15.renderedDOM,
        props = _setup15.props;

    var _TestUtils$scryRender5 = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, 'one'),
        _TestUtils$scryRender6 = _slicedToArray(_TestUtils$scryRender5, 1),
        listItem = _TestUtils$scryRender6[0];

    TestUtils.Simulate.click(listItem);
    (0, _expect["default"])(props.onChange).toHaveBeenCalledWith('1', {
      id: '1',
      text: 'one'
    });
  });
  it('Should not call onChange func, When is readonly component', function () {
    var defaultProps = {
      options: [{
        id: '1',
        text: 'one'
      }, {
        id: '2',
        text: 'two'
      }],
      onChange: jest.fn(),
      isReadOnly: true
    };

    var _setup16 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup16.renderedDOM;

    var listItems = TestUtils.scryRenderedComponentsWithTestid(renderedDOM, '1');
    (0, _expect["default"])(listItems.length).toBe(0);
  });
  it('Should call getNextOptions, When on reach boundary and isNextOptions is true', function () {
    var defaultProps = {
      options: [1, 2, 3, 4, 5],
      getNextOptions: jest.fn(),
      isNextOptions: true,
      isPopupOpen: true
    };

    var _setup17 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup17.renderedDOM,
        props = _setup17.props;

    var searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    (0, _expect["default"])(props.getNextOptions).toHaveBeenCalled();
  });
  it('Should not call getNextOptions, When on reach boundary and isNextOptions is false', function () {
    var defaultProps = {
      options: [1, 2, 3, 4, 5],
      getNextOptions: jest.fn(),
      isNextOptions: false,
      isPopupOpen: true
    };

    var _setup18 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup18.renderedDOM,
        props = _setup18.props;

    var searchBox = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    TestUtils.Simulate.keyDown(searchBox, {
      keyCode: 40
    });
    (0, _expect["default"])(props.getNextOptions).not.toHaveBeenCalled();
  });
  it('Should ignore excludeOptions', function () {
    var defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      excludeOptions: ['1', '2'],
      isPopupOpen: true
    };

    var _setup19 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup19.renderedDOM; // let liteItemArr = TestUtils.scryRenderedComponentsWithTestid(
    //   renderedDOM,
    //   'listItem'
    // );


    var liteItemArr = TestUtils.scryRenderedComponentsWithType(renderedDOM, _ListItem["default"]);
    (0, _expect["default"])(liteItemArr.length).toBe(3);
  });
  it('Should select defaultValue', function () {
    var defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      isDefaultSelectValue: true
    };

    var _setup20 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup20.renderedDOM;

    var selectComp = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    (0, _expect["default"])(selectComp.value).toBe('1');
  });
  it('Should not select defaultValue', function () {
    var defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      isDefaultSelectValue: false
    };

    var _setup21 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup21.renderedDOM;

    var selectComp = TestUtils.findRenderedComponentsWithTestid(renderedDOM, 'selectComponent_textBox');
    (0, _expect["default"])(selectComp.value).toBe('');
  });
  it('Should active selected value', function () {
    var defaultProps = {
      options: ['1', '2', '3', '4', '5'],
      selectedValue: '1',
      isPopupOpen: true
    };

    var _setup22 = setup(_Select["default"], defaultProps),
        renderedDOM = _setup22.renderedDOM;

    var _TestUtils$scryRender7 = TestUtils.scryRenderedComponentsWithType(renderedDOM, _ListItem["default"]),
        _TestUtils$scryRender8 = _slicedToArray(_TestUtils$scryRender7, 2),
        listItem1 = _TestUtils$scryRender8[0],
        listItem2 = _TestUtils$scryRender8[1];

    (0, _expect["default"])(listItem1.props.active).toBeTruthy();
    (0, _expect["default"])(listItem2.props.active).toBeFalsy();
  });
});